---
title: <span class="badge builder"></span> Manifest
---
# <span class="badge builder"></span> Manifest

## Constructor

```python
Manifest()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> resource.Manifest
```

### <span class="badge object-method"></span> api_version

```python
def api_version(api_version: str) -> typing.Self
```

### <span class="badge object-method"></span> kind

```python
def kind(kind: str) -> typing.Self
```

### <span class="badge object-method"></span> metadata

```python
def metadata(metadata: cogbuilder.Builder[resource.Metadata]) -> typing.Self
```

### <span class="badge object-method"></span> spec

```python
def spec(spec: object) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Manifest](./object-Manifest.md)
